pub struct FallbackCacheManager { /* private fields */ }Expand description
Cache manager that wraps a primary (Redis/Redis Cluster) cache and automatically falls back to in-memory cache when the primary becomes unavailable.
When the primary cache recovers, data from the fallback cache is synchronized back to the primary before switching over to prevent data loss.
Implementations
Sourceimpl FallbackCacheManager
impl FallbackCacheManager
Sourcepub fn new(
primary: Box<dyn CacheManager + Send + Sync>,
fallback_options: MemoryCacheOptions,
) -> Self
pub fn new( primary: Box<dyn CacheManager + Send + Sync>, fallback_options: MemoryCacheOptions, ) -> Self
Creates a new FallbackCacheManager without performing an initial health check. If Redis is unavailable at startup, the first cache operation will experience higher latency due to the failed attempt and retry.
Sourcepub async fn new_with_health_check(
primary: Box<dyn CacheManager + Send + Sync>,
fallback_options: MemoryCacheOptions,
) -> Self
pub async fn new_with_health_check( primary: Box<dyn CacheManager + Send + Sync>, fallback_options: MemoryCacheOptions, ) -> Self
Creates a new FallbackCacheManager and performs an initial health check on the primary cache. If the primary cache is unavailable at startup, immediately switches to fallback mode, avoiding initial latency on the first cache operation.